'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var styled = require('styled-components');
var styled__default = _interopDefault(styled);
var polished = require('polished');
var React = _interopDefault(require('react'));

function sassRgba(color, alpha) {
  return polished.rgba(Object.assign(polished.parseToRgb(color), { alpha: alpha }));
}

// General variable structure

// Colors
//
// Grayscale and brand colors for use across Bootstrap.

// Start with assigning color names to specific hex values.
var white = '#fff';
var black = '#000';
var red = '#d9534f';
var orange = '#f0ad4e';

var green = '#5cb85c';
var blue = '#0275d8';
var teal = '#5bc0de';



// Create grayscale
var grayDark = '#292b2c';

var grayLight = '#636c72';
var grayLighter = '#eceeef';


// Reassign color vars to semantic color scheme
var brandPrimary = blue;
var brandSuccess = green;
var brandInfo = teal;
var brandWarning = orange;
var brandDanger = red;


// Options
//
// Quickly modify global styling by enabling or disabling optional features.

var enableRounded = true;
var enableShadows = false;

var enableTransitions = true;
var enableHoverMediaQuery = false;



// Spacing
//
// Control the default styling of most Bootstrap elements by modifying these
// variables. Mostly focused on spacing.
// You can add more entries to the $spacers map, should you need more variation.

// export const spacer = '1rem';





var borderWidth = '1px';

// This variable affects the `.h-*` and `.w-*` classes.


// Body
//
// Settings for the `<body>` element.






// Links
//
// Style anchor elements.

var linkColor = brandPrimary;

var linkHoverColor = polished.darken(0.15, linkColor);


// Components
//
// Define common padding and border radius sizes and more.




var borderRadius$1 = '0.25rem';
var borderRadiusLg = '0.3rem';
var borderRadiusSm = '0.2rem';






var transitionBase = 'all .2s ease-in-out';



// Fonts
//
// Font, lineHeight, and color for body text, headings, and more.






var fontSizeBase = '1rem';
var fontSizeLg = '1.25rem';
var fontSizeSm = '0.875rem';


var fontWeightNormal = 'normal';
var fontWeightBold = 'bold';

















// Form states and alerts
//
// Define colors for form feedback states and, by default, alerts.

var stateSuccessText = '#3c763d';
var stateSuccessBg = '#dff0d8';
var stateSuccessBorderColor = polished.darken(0.05, stateSuccessBg);

var stateInfoText = '#31708f';
var stateInfoBg = '#d9edf7';
var stateInfoBorderColor = polished.darken(0.07, stateInfoBg);

var stateWarningText = '#8a6d3b';
var stateWarningBg = '#fcf8e3';

var stateWarningBorderColor = polished.darken(0.05, stateWarningBg);

var stateDangerText = '#a94442';
var stateDangerBg = '#f2dede';
var stateDangerBorderColor = polished.darken(0.05, stateDangerBg);

// Badges

var badgeDefaultBg = grayLight;
var badgePrimaryBg = brandPrimary;
var badgeSuccessBg = brandSuccess;
var badgeInfoBg = brandInfo;
var badgeWarningBg = brandWarning;
var badgeDangerBg = brandDanger;

var badgeColor = white;
var badgeLinkHoverColor = white;
var badgeFontSize = '75%';
var badgeFontWeight = fontWeightBold;
var badgePaddingY = '.25em';
var badgePaddingX = '.4em';

var badgePillPaddingX = '.6em';
// Use a higher than normal value to ensure completely rounded edges when
// customizing padding or fontSize on labels.
var badgePillBorderRadius = '10rem';

// Buttons
//
// For each of Bootstrap's buttons, define text, background and border color.

var inputBtnPaddingY = '.5rem';
var inputBtnPaddingX = '1rem';
var inputBtnLineHeight = 1.25;

var inputBtnPaddingYsm = '.25rem';
var inputBtnPaddingXsm = '.5rem';
var inputBtnLineHeightSm = 1.5;

var inputBtnPaddingYlg = '.5rem';
var inputBtnPaddingXlg = '1rem';
var inputBtnLineHeightLg = 1.5;

var btnFontWeight = fontWeightNormal;
var btnBoxShadow = 'inset 0 1px 0 ' + sassRgba(white, .15) + ', 0 1px 1px ' + sassRgba(black, .075);
var btnFocusBoxShadow = '0 0 0 2px ' + sassRgba(brandPrimary, .25);
var btnActiveBoxShadow = 'inset 0 3px 5px rgba($black,.125)';

var btnPrimaryColor = white;
var btnPrimaryBg = brandPrimary;
var btnPrimaryBorderColor = btnPrimaryBg;

var btnSecondaryColor = grayDark;
var btnSecondaryBg = white;
var btnSecondaryBorderColor = '#ccc';

var btnInfoColor = white;
var btnInfoBg = brandInfo;
var btnInfoBorderColor = btnInfoBg;

var btnSuccessColor = white;
var btnSuccessBg = brandSuccess;
var btnSuccessBorderColor = btnSuccessBg;

var btnWarningColor = white;
var btnWarningBg = brandWarning;
var btnWarningBorderColor = btnWarningBg;

var btnDangerColor = white;
var btnDangerBg = brandDanger;
var btnDangerBorderColor = btnDangerBg;

var btnLinkDisabledColor = grayLight;

var btnBlockSpacingY = '.5rem';

// Allows for customizing button radius independently from global border radius
var btnBorderRadius = borderRadius$1;
var btnBorderRadiusLg = borderRadiusLg;
var btnBorderRadiusSm = borderRadiusSm;

var btnTransition = 'all .2s ease-in-out';

// Forms





var inputBorderColor = sassRgba(black, .15);
var inputBtnBorderWidth = borderWidth; // For form controls ans
var inputBoxShadow = 'inset 0 1px 1px ' + sassRgba(black, .075);





var inputBorderColorFocus = polished.lighten(.25, brandPrimary);
var inputBoxShadowFocus = inputBoxShadow + ', ' + sassRgba(inputBorderColorFocus, .6);









// Dropdowns
//
// Dropdown menu container and contents.





var dropdownBorderColor = sassRgba(black, .15);


var dropdownBoxShadow = '0 .5rem 1rem ' + sassRgba(black, .175);


var dropdownLinkHoverColor = polished.darken(0.05, grayDark);












// Alerts
//
// Define alert colors, border radius, and padding.

var alertPaddingY = '.75rem';
var alertPaddingX = '1.25rem';
var alertMarginBottom = '1rem';
var alertBorderRadius = borderRadius$1;
var alertLinkFontWeight = fontWeightBold;
var alertBorderWidth = borderWidth;

var alertSuccessBg = stateSuccessBg;
var alertSuccessText = stateSuccessText;
var alertSuccessBorderColor = stateSuccessBorderColor;

var alertInfoBg = stateInfoBg;
var alertInfoText = stateInfoText;
var alertInfoBorderColor = stateInfoBorderColor;

var alertWarningBg = stateWarningBg;
var alertWarningText = stateWarningText;
var alertWarningBorderColor = stateWarningBorderColor;

var alertDangerBg = stateDangerBg;
var alertDangerText = stateDangerText;
var alertDangerBorderColor = stateDangerBorderColor;

// Grid columns
//
// Set the number of columns and specify the width of the gutters.





// Breadcrumbs

var breadcrumbPaddingY = '.75rem';
var breadcrumbPaddingX = '1rem';
var breadcrumbItemPadding = '.5rem';
var breadcrumbBg = grayLighter;
var breadcrumbDividerColor = grayLight;
var breadcrumbActiveColor = grayLight;
var breadcrumbDivider = '"/"';

var taggedTemplateLiteral = function (strings, raw) {
  return Object.freeze(Object.defineProperties(strings, {
    raw: {
      value: Object.freeze(raw)
    }
  }));
};

var _templateObject$1 = taggedTemplateLiteral(['\n      border-radius: ', ';\n    '], ['\n      border-radius: ', ';\n    ']);
var _templateObject2 = taggedTemplateLiteral(['\n      border-top-right-radius: ', ';\n      border-top-left-radius: ', ';\n    '], ['\n      border-top-right-radius: ', ';\n      border-top-left-radius: ', ';\n    ']);
var _templateObject3 = taggedTemplateLiteral(['\n      border-bottom-right-radius: ', ';\n      border-top-right-radius: $radius;\n    '], ['\n      border-bottom-right-radius: ', ';\n      border-top-right-radius: $radius;\n    ']);
var _templateObject4 = taggedTemplateLiteral(['\n      border-bottom-right-radius: ', ';\n      border-bottom-left-radius: ', ';\n    '], ['\n      border-bottom-right-radius: ', ';\n      border-bottom-left-radius: ', ';\n    ']);
var _templateObject5 = taggedTemplateLiteral(['\n      border-bottom-left-radius: ', ';\n      border-top-left-radius: ', ';\n    '], ['\n      border-bottom-left-radius: ', ';\n      border-top-left-radius: ', ';\n    ']);

function borderRadius() {
  var radius = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '0.25rem';

  if (enableRounded) {
    return styled.css(_templateObject$1, radius);
  }
}

var _templateObject$2 = taggedTemplateLiteral(['\n    color: ', ';\n    background-color: ', ';\n    border-color: ', ';\n\n    hr {\n      border-top-color: ', ';\n    }\n\n    a {\n      color: ', ';\n    }\n  '], ['\n    color: ', ';\n    background-color: ', ';\n    border-color: ', ';\n\n    hr {\n      border-top-color: ', ';\n    }\n\n    a {\n      color: ', ';\n    }\n  ']);

function alertVariant(background, border, bodyColor) {
  return styled.css(_templateObject$2, bodyColor, background, border, polished.darken(0.05, border), polished.darken(0.1, bodyColor));
}

var _templateObject$4 = taggedTemplateLiteral(['\n  &:hover { ', ' }\n'], ['\n  &:hover { ', ' }\n']);
var _templateObject2$1 = taggedTemplateLiteral(['\n      &:focus { ', '} }\n      ', '\n    '], ['\n      &:focus { ', '} }\n      ', '\n    ']);
var _templateObject3$1 = taggedTemplateLiteral(['\n    &:focus,\n    &:hover {\n      ', '\n    }\n  '], ['\n    &:focus,\n    &:hover {\n      ', '\n    }\n  ']);
var _templateObject4$1 = taggedTemplateLiteral(['\n      &,\n      &:focus {\n        ', '\n      }\n      ', '\n    '], ['\n      &,\n      &:focus {\n        ', '\n      }\n      ', '\n    ']);
var _templateObject5$1 = taggedTemplateLiteral(['\n    &,\n    &:focus,\n    &:hover {\n      ', '\n    }\n  '], ['\n    &,\n    &:focus,\n    &:hover {\n      ', '\n    }\n  ']);
var _templateObject6 = taggedTemplateLiteral(['\n      &:focus,\n      &:active {\n        ', '\n      }\n      ', '\n    '], ['\n      &:focus,\n      &:active {\n        ', '\n      }\n      ', '\n    ']);
var _templateObject7 = taggedTemplateLiteral(['\n    &:focus,\n    &:active,\n    &:hover {\n      ', '\n    }\n  '], ['\n    &:focus,\n    &:active,\n    &:hover {\n      ', '\n    }\n  ']);

var hover = function hover(content) {
  return styled.css(_templateObject$4, content);
};

var hoverFocus = function hoverFocus(content) {
  if (enableHoverMediaQuery) {
    return styled.css(_templateObject2$1, content, hover(content));
  }

  return styled.css(_templateObject3$1, content);
};

var _templateObject$3 = taggedTemplateLiteral(['\n  font-size: ', ';\n  font-weight: ', ';\n  line-height: 1;\n  color: ', ';\n  text-shadow: ', ';\n  opacity: .5;\n\n  ', ';\n\n  padding: 0;\n  background: transparent;\n  border: 0;\n  -webkit-appearance: none;\n'], ['\n  font-size: ', ';\n  font-weight: ', ';\n  line-height: 1;\n  color: ', ';\n  text-shadow: ', ';\n  opacity: .5;\n\n  ', ';\n\n  padding: 0;\n  background: transparent;\n  border: 0;\n  -webkit-appearance: none;\n']);

var StyledCloseIcon = styled__default.button(_templateObject$3, function (props) {
  return props.theme.closeFontSize;
}, function (props) {
  return props.theme.closeFontWeight;
}, function (props) {
  return props.theme.closeColor;
}, function (props) {
  return props.theme.closeTextShadow;
}, hoverFocus('\n    color: ' + function (props) {
  return props.theme.closeColor;
} + ';\n    text-decoration: none;\n    opacity: .75;\n  '));

var CloseIcon = function CloseIcon(props) {
  return React.createElement(
    StyledCloseIcon,
    props,
    React.createElement(
      'span',
      { 'aria-hidden': 'true' },
      '\xD7'
    )
  );
};

CloseIcon.defaultProps = {
  theme: {
    closeFontSize: polished.stripUnit(fontSizeBase) * 1.5 + 'rem',
    closeFontWeight: fontWeightBold,
    closeColor: black,
    closeTextWhadow: '0 1px 0 ' + white
  }
};

var _templateObject = taggedTemplateLiteral(['\n  ', '\n  margin-bottom: ', ';\n  border: ', ' solid transparent;\n\n  a {\n    font-weight: ', ';\n  }\n\n  ', '\n\n  ', '\n\n  ', ' {\n    position: relative;\n    float: right;\n    top: -', ';\n    right: -', ';\n    ', '\n    color: inherit;\n  }\n'], ['\n  ', '\n  margin-bottom: ', ';\n  border: ', ' solid transparent;\n\n  a {\n    font-weight: ', ';\n  }\n\n  ', '\n\n  ', '\n\n  ', ' {\n    position: relative;\n    float: right;\n    top: -', ';\n    right: -', ';\n    ', '\n    color: inherit;\n  }\n']);

var Alert = styled__default.div(_templateObject, function (props) {
  return 'padding: ' + props.theme.alertPaddingY + ' ' + props.theme.alertPaddingX + ';';
}, function (props) {
  return props.theme.alertMarginBottom;
}, function (props) {
  return props.theme.alertBorderWidth;
}, function (props) {
  return props.theme.alertLinkFontWeight;
}, function (props) {
  return borderRadius(props.theme.alertBorderRadius);
}, function (_ref) {
  var theme = _ref.theme,
      type = _ref.type;

  switch (type) {
    case 'success':
      return alertVariant(theme.alertSuccessBg, theme.alertSuccessBorderColor, theme.alertSuccessText);
    case 'info':
      return alertVariant(theme.alertInfoBg, theme.alertInfoBorderColor, theme.alertInfoText);
    case 'warning':
      return alertVariant(theme.alertWarningBg, theme.alertWarningBorderColor, theme.alertWarningText);
    case 'danger':
      return alertVariant(theme.alertDangerBg, theme.alertDangerBorderColor, theme.alertDangerText);
    default:
      return null;
  }
}, StyledCloseIcon, function (props) {
  return props.theme.alertPaddingY;
}, function (props) {
  return props.theme.alertPaddingX;
}, function (props) {
  return 'padding: ' + props.theme.alertPaddingY + ' ' + props.theme.alertPaddingX + ';';
});

Alert.defaultProps = {
  theme: {
    alertPaddingY: alertPaddingY,
    alertPaddingX: alertPaddingX,
    alertMarginBottom: alertMarginBottom,
    alertBorderRadius: alertBorderRadius,
    alertLinkFontWeight: alertLinkFontWeight,
    alertBorderWidth: alertBorderWidth,

    alertSuccessBg: alertSuccessBg,
    alertSuccessText: alertSuccessText,
    alertSuccessBorderColor: alertSuccessBorderColor,

    alertInfoBg: alertInfoBg,
    alertInfoText: alertInfoText,
    alertInfoBorderColor: alertInfoBorderColor,

    alertWarningBg: alertWarningBg,
    alertWarningText: alertWarningText,
    alertWarningBorderColor: alertWarningBorderColor,

    alertDangerBg: alertDangerBg,
    alertDangerText: alertDangerText,
    alertDangerBorderColor: alertDangerBorderColor
  }
};

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

/**
 * Copyright (c) 2013-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * LICENSE file in the root directory of this source tree. An additional grant
 * of patent rights can be found in the PATENTS file in the same directory.
 *
 * 
 */

function makeEmptyFunction(arg) {
  return function () {
    return arg;
  };
}

/**
 * This function accepts and discards inputs; it has no side effects. This is
 * primarily useful idiomatically for overridable function endpoints which
 * always need to be callable, since JS lacks a null-call idiom ala Cocoa.
 */
var emptyFunction = function emptyFunction() {};

emptyFunction.thatReturns = makeEmptyFunction;
emptyFunction.thatReturnsFalse = makeEmptyFunction(false);
emptyFunction.thatReturnsTrue = makeEmptyFunction(true);
emptyFunction.thatReturnsNull = makeEmptyFunction(null);
emptyFunction.thatReturnsThis = function () {
  return this;
};
emptyFunction.thatReturnsArgument = function (arg) {
  return arg;
};

var emptyFunction_1 = emptyFunction;

/**
 * Copyright (c) 2013-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * LICENSE file in the root directory of this source tree. An additional grant
 * of patent rights can be found in the PATENTS file in the same directory.
 *
 */

/**
 * Use invariant() to assert state which your program assumes to be true.
 *
 * Provide sprintf-style format (only %s is supported) and arguments
 * to provide information about what broke and what you were
 * expecting.
 *
 * The invariant message will be stripped in production, but the invariant
 * will remain to ensure logic does not differ in production.
 */

var validateFormat = function validateFormat(format) {};

if (process.env.NODE_ENV !== 'production') {
  validateFormat = function validateFormat(format) {
    if (format === undefined) {
      throw new Error('invariant requires an error message argument');
    }
  };
}

function invariant(condition, format, a, b, c, d, e, f) {
  validateFormat(format);

  if (!condition) {
    var error;
    if (format === undefined) {
      error = new Error('Minified exception occurred; use the non-minified dev environment ' + 'for the full error message and additional helpful warnings.');
    } else {
      var args = [a, b, c, d, e, f];
      var argIndex = 0;
      error = new Error(format.replace(/%s/g, function () {
        return args[argIndex++];
      }));
      error.name = 'Invariant Violation';
    }

    error.framesToPop = 1; // we don't care about invariant's own frame
    throw error;
  }
}

var invariant_1 = invariant;

/**
 * Similar to invariant but only logs a warning if the condition is not met.
 * This can be used to log issues in development environments in critical
 * paths. Removing the logging code for production environments will keep the
 * same logic and follow the same code paths.
 */

var warning = emptyFunction_1;

if (process.env.NODE_ENV !== 'production') {
  (function () {
    var printWarning = function printWarning(format) {
      for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        args[_key - 1] = arguments[_key];
      }

      var argIndex = 0;
      var message = 'Warning: ' + format.replace(/%s/g, function () {
        return args[argIndex++];
      });
      if (typeof console !== 'undefined') {
        console.error(message);
      }
      try {
        // --- Welcome to debugging React ---
        // This error was thrown as a convenience so that you can use this stack
        // to find the callsite that caused this warning to fire.
        throw new Error(message);
      } catch (x) {}
    };

    warning = function warning(condition, format) {
      if (format === undefined) {
        throw new Error('`warning(condition, format, ...args)` requires a warning ' + 'message argument');
      }

      if (format.indexOf('Failed Composite propType: ') === 0) {
        return; // Ignore CompositeComponent proptype check.
      }

      if (!condition) {
        for (var _len2 = arguments.length, args = Array(_len2 > 2 ? _len2 - 2 : 0), _key2 = 2; _key2 < _len2; _key2++) {
          args[_key2 - 2] = arguments[_key2];
        }

        printWarning.apply(undefined, [format].concat(args));
      }
    };
  })();
}

var warning_1 = warning;

/**
 * Copyright 2013-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * LICENSE file in the root directory of this source tree. An additional grant
 * of patent rights can be found in the PATENTS file in the same directory.
 */

var ReactPropTypesSecret = 'SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED';

var ReactPropTypesSecret_1 = ReactPropTypesSecret;

if (process.env.NODE_ENV !== 'production') {
  var invariant$1 = invariant_1;
  var warning$1 = warning_1;
  var ReactPropTypesSecret$1 = ReactPropTypesSecret_1;
  var loggedTypeFailures = {};
}

/**
 * Assert that the values match with the type specs.
 * Error messages are memorized and will only be shown once.
 *
 * @param {object} typeSpecs Map of name to a ReactPropType
 * @param {object} values Runtime values that need to be type-checked
 * @param {string} location e.g. "prop", "context", "child context"
 * @param {string} componentName Name of the component for error messages.
 * @param {?Function} getStack Returns the component stack.
 * @private
 */
function checkPropTypes(typeSpecs, values, location, componentName, getStack) {
  if (process.env.NODE_ENV !== 'production') {
    for (var typeSpecName in typeSpecs) {
      if (typeSpecs.hasOwnProperty(typeSpecName)) {
        var error;
        // Prop type validation may throw. In case they do, we don't want to
        // fail the render phase where it didn't fail before. So we log it.
        // After these have been cleaned up, we'll let them throw.
        try {
          // This is intentionally an invariant that gets caught. It's the same
          // behavior as without this statement except with a better message.
          invariant$1(typeof typeSpecs[typeSpecName] === 'function', '%s: %s type `%s` is invalid; it must be a function, usually from ' + 'React.PropTypes.', componentName || 'React class', location, typeSpecName);
          error = typeSpecs[typeSpecName](values, typeSpecName, componentName, location, null, ReactPropTypesSecret$1);
        } catch (ex) {
          error = ex;
        }
        warning$1(!error || error instanceof Error, '%s: type specification of %s `%s` is invalid; the type checker ' + 'function must return `null` or an `Error` but returned a %s. ' + 'You may have forgotten to pass an argument to the type checker ' + 'creator (arrayOf, instanceOf, objectOf, oneOf, oneOfType, and ' + 'shape all require an argument).', componentName || 'React class', location, typeSpecName, typeof error);
        if (error instanceof Error && !(error.message in loggedTypeFailures)) {
          // Only monitor this failure once because there tends to be a lot of the
          // same error.
          loggedTypeFailures[error.message] = true;

          var stack = getStack ? getStack() : '';

          warning$1(false, 'Failed %s type: %s%s', location, error.message, stack != null ? stack : '');
        }
      }
    }
  }
}

var checkPropTypes_1 = checkPropTypes;

var factoryWithTypeCheckers = function(isValidElement, throwOnDirectAccess) {
  /* global Symbol */
  var ITERATOR_SYMBOL = typeof Symbol === 'function' && Symbol.iterator;
  var FAUX_ITERATOR_SYMBOL = '@@iterator'; // Before Symbol spec.

  /**
   * Returns the iterator method function contained on the iterable object.
   *
   * Be sure to invoke the function with the iterable as context:
   *
   *     var iteratorFn = getIteratorFn(myIterable);
   *     if (iteratorFn) {
   *       var iterator = iteratorFn.call(myIterable);
   *       ...
   *     }
   *
   * @param {?object} maybeIterable
   * @return {?function}
   */
  function getIteratorFn(maybeIterable) {
    var iteratorFn = maybeIterable && (ITERATOR_SYMBOL && maybeIterable[ITERATOR_SYMBOL] || maybeIterable[FAUX_ITERATOR_SYMBOL]);
    if (typeof iteratorFn === 'function') {
      return iteratorFn;
    }
  }

  /**
   * Collection of methods that allow declaration and validation of props that are
   * supplied to React components. Example usage:
   *
   *   var Props = require('ReactPropTypes');
   *   var MyArticle = React.createClass({
   *     propTypes: {
   *       // An optional string prop named "description".
   *       description: Props.string,
   *
   *       // A required enum prop named "category".
   *       category: Props.oneOf(['News','Photos']).isRequired,
   *
   *       // A prop named "dialog" that requires an instance of Dialog.
   *       dialog: Props.instanceOf(Dialog).isRequired
   *     },
   *     render: function() { ... }
   *   });
   *
   * A more formal specification of how these methods are used:
   *
   *   type := array|bool|func|object|number|string|oneOf([...])|instanceOf(...)
   *   decl := ReactPropTypes.{type}(.isRequired)?
   *
   * Each and every declaration produces a function with the same signature. This
   * allows the creation of custom validation functions. For example:
   *
   *  var MyLink = React.createClass({
   *    propTypes: {
   *      // An optional string or URI prop named "href".
   *      href: function(props, propName, componentName) {
   *        var propValue = props[propName];
   *        if (propValue != null && typeof propValue !== 'string' &&
   *            !(propValue instanceof URI)) {
   *          return new Error(
   *            'Expected a string or an URI for ' + propName + ' in ' +
   *            componentName
   *          );
   *        }
   *      }
   *    },
   *    render: function() {...}
   *  });
   *
   * @internal
   */

  var ANONYMOUS = '<<anonymous>>';

  // Important!
  // Keep this list in sync with production version in `./factoryWithThrowingShims.js`.
  var ReactPropTypes = {
    array: createPrimitiveTypeChecker('array'),
    bool: createPrimitiveTypeChecker('boolean'),
    func: createPrimitiveTypeChecker('function'),
    number: createPrimitiveTypeChecker('number'),
    object: createPrimitiveTypeChecker('object'),
    string: createPrimitiveTypeChecker('string'),
    symbol: createPrimitiveTypeChecker('symbol'),

    any: createAnyTypeChecker(),
    arrayOf: createArrayOfTypeChecker,
    element: createElementTypeChecker(),
    instanceOf: createInstanceTypeChecker,
    node: createNodeChecker(),
    objectOf: createObjectOfTypeChecker,
    oneOf: createEnumTypeChecker,
    oneOfType: createUnionTypeChecker,
    shape: createShapeTypeChecker
  };

  /**
   * inlined Object.is polyfill to avoid requiring consumers ship their own
   * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/is
   */
  /*eslint-disable no-self-compare*/
  function is(x, y) {
    // SameValue algorithm
    if (x === y) {
      // Steps 1-5, 7-10
      // Steps 6.b-6.e: +0 != -0
      return x !== 0 || 1 / x === 1 / y;
    } else {
      // Step 6.a: NaN == NaN
      return x !== x && y !== y;
    }
  }
  /*eslint-enable no-self-compare*/

  /**
   * We use an Error-like object for backward compatibility as people may call
   * PropTypes directly and inspect their output. However, we don't use real
   * Errors anymore. We don't inspect their stack anyway, and creating them
   * is prohibitively expensive if they are created too often, such as what
   * happens in oneOfType() for any type before the one that matched.
   */
  function PropTypeError(message) {
    this.message = message;
    this.stack = '';
  }
  // Make `instanceof Error` still work for returned errors.
  PropTypeError.prototype = Error.prototype;

  function createChainableTypeChecker(validate) {
    if (process.env.NODE_ENV !== 'production') {
      var manualPropTypeCallCache = {};
      var manualPropTypeWarningCount = 0;
    }
    function checkType(isRequired, props, propName, componentName, location, propFullName, secret) {
      componentName = componentName || ANONYMOUS;
      propFullName = propFullName || propName;

      if (secret !== ReactPropTypesSecret_1) {
        if (throwOnDirectAccess) {
          // New behavior only for users of `prop-types` package
          invariant_1(
            false,
            'Calling PropTypes validators directly is not supported by the `prop-types` package. ' +
            'Use `PropTypes.checkPropTypes()` to call them. ' +
            'Read more at http://fb.me/use-check-prop-types'
          );
        } else if (process.env.NODE_ENV !== 'production' && typeof console !== 'undefined') {
          // Old behavior for people using React.PropTypes
          var cacheKey = componentName + ':' + propName;
          if (
            !manualPropTypeCallCache[cacheKey] &&
            // Avoid spamming the console because they are often not actionable except for lib authors
            manualPropTypeWarningCount < 3
          ) {
            warning_1(
              false,
              'You are manually calling a React.PropTypes validation ' +
              'function for the `%s` prop on `%s`. This is deprecated ' +
              'and will throw in the standalone `prop-types` package. ' +
              'You may be seeing this warning due to a third-party PropTypes ' +
              'library. See https://fb.me/react-warning-dont-call-proptypes ' + 'for details.',
              propFullName,
              componentName
            );
            manualPropTypeCallCache[cacheKey] = true;
            manualPropTypeWarningCount++;
          }
        }
      }
      if (props[propName] == null) {
        if (isRequired) {
          if (props[propName] === null) {
            return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required ' + ('in `' + componentName + '`, but its value is `null`.'));
          }
          return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required in ' + ('`' + componentName + '`, but its value is `undefined`.'));
        }
        return null;
      } else {
        return validate(props, propName, componentName, location, propFullName);
      }
    }

    var chainedCheckType = checkType.bind(null, false);
    chainedCheckType.isRequired = checkType.bind(null, true);

    return chainedCheckType;
  }

  function createPrimitiveTypeChecker(expectedType) {
    function validate(props, propName, componentName, location, propFullName, secret) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== expectedType) {
        // `propValue` being instance of, say, date/regexp, pass the 'object'
        // check, but we can offer a more precise error message here rather than
        // 'of type `object`'.
        var preciseType = getPreciseType(propValue);

        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + preciseType + '` supplied to `' + componentName + '`, expected ') + ('`' + expectedType + '`.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createAnyTypeChecker() {
    return createChainableTypeChecker(emptyFunction_1.thatReturnsNull);
  }

  function createArrayOfTypeChecker(typeChecker) {
    function validate(props, propName, componentName, location, propFullName) {
      if (typeof typeChecker !== 'function') {
        return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside arrayOf.');
      }
      var propValue = props[propName];
      if (!Array.isArray(propValue)) {
        var propType = getPropType(propValue);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an array.'));
      }
      for (var i = 0; i < propValue.length; i++) {
        var error = typeChecker(propValue, i, componentName, location, propFullName + '[' + i + ']', ReactPropTypesSecret_1);
        if (error instanceof Error) {
          return error;
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createElementTypeChecker() {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      if (!isValidElement(propValue)) {
        var propType = getPropType(propValue);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected a single ReactElement.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createInstanceTypeChecker(expectedClass) {
    function validate(props, propName, componentName, location, propFullName) {
      if (!(props[propName] instanceof expectedClass)) {
        var expectedClassName = expectedClass.name || ANONYMOUS;
        var actualClassName = getClassName(props[propName]);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + actualClassName + '` supplied to `' + componentName + '`, expected ') + ('instance of `' + expectedClassName + '`.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createEnumTypeChecker(expectedValues) {
    if (!Array.isArray(expectedValues)) {
      process.env.NODE_ENV !== 'production' ? warning_1(false, 'Invalid argument supplied to oneOf, expected an instance of array.') : void 0;
      return emptyFunction_1.thatReturnsNull;
    }

    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      for (var i = 0; i < expectedValues.length; i++) {
        if (is(propValue, expectedValues[i])) {
          return null;
        }
      }

      var valuesString = JSON.stringify(expectedValues);
      return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of value `' + propValue + '` ' + ('supplied to `' + componentName + '`, expected one of ' + valuesString + '.'));
    }
    return createChainableTypeChecker(validate);
  }

  function createObjectOfTypeChecker(typeChecker) {
    function validate(props, propName, componentName, location, propFullName) {
      if (typeof typeChecker !== 'function') {
        return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside objectOf.');
      }
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an object.'));
      }
      for (var key in propValue) {
        if (propValue.hasOwnProperty(key)) {
          var error = typeChecker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
          if (error instanceof Error) {
            return error;
          }
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createUnionTypeChecker(arrayOfTypeCheckers) {
    if (!Array.isArray(arrayOfTypeCheckers)) {
      process.env.NODE_ENV !== 'production' ? warning_1(false, 'Invalid argument supplied to oneOfType, expected an instance of array.') : void 0;
      return emptyFunction_1.thatReturnsNull;
    }

    for (var i = 0; i < arrayOfTypeCheckers.length; i++) {
      var checker = arrayOfTypeCheckers[i];
      if (typeof checker !== 'function') {
        warning_1(
          false,
          'Invalid argument supplid to oneOfType. Expected an array of check functions, but ' +
          'received %s at index %s.',
          getPostfixForTypeWarning(checker),
          i
        );
        return emptyFunction_1.thatReturnsNull;
      }
    }

    function validate(props, propName, componentName, location, propFullName) {
      for (var i = 0; i < arrayOfTypeCheckers.length; i++) {
        var checker = arrayOfTypeCheckers[i];
        if (checker(props, propName, componentName, location, propFullName, ReactPropTypesSecret_1) == null) {
          return null;
        }
      }

      return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`.'));
    }
    return createChainableTypeChecker(validate);
  }

  function createNodeChecker() {
    function validate(props, propName, componentName, location, propFullName) {
      if (!isNode(props[propName])) {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`, expected a ReactNode.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createShapeTypeChecker(shapeTypes) {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type `' + propType + '` ' + ('supplied to `' + componentName + '`, expected `object`.'));
      }
      for (var key in shapeTypes) {
        var checker = shapeTypes[key];
        if (!checker) {
          continue;
        }
        var error = checker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
        if (error) {
          return error;
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function isNode(propValue) {
    switch (typeof propValue) {
      case 'number':
      case 'string':
      case 'undefined':
        return true;
      case 'boolean':
        return !propValue;
      case 'object':
        if (Array.isArray(propValue)) {
          return propValue.every(isNode);
        }
        if (propValue === null || isValidElement(propValue)) {
          return true;
        }

        var iteratorFn = getIteratorFn(propValue);
        if (iteratorFn) {
          var iterator = iteratorFn.call(propValue);
          var step;
          if (iteratorFn !== propValue.entries) {
            while (!(step = iterator.next()).done) {
              if (!isNode(step.value)) {
                return false;
              }
            }
          } else {
            // Iterator will provide entry [k,v] tuples rather than values.
            while (!(step = iterator.next()).done) {
              var entry = step.value;
              if (entry) {
                if (!isNode(entry[1])) {
                  return false;
                }
              }
            }
          }
        } else {
          return false;
        }

        return true;
      default:
        return false;
    }
  }

  function isSymbol(propType, propValue) {
    // Native Symbol.
    if (propType === 'symbol') {
      return true;
    }

    // 19.4.3.5 Symbol.prototype[@@toStringTag] === 'Symbol'
    if (propValue['@@toStringTag'] === 'Symbol') {
      return true;
    }

    // Fallback for non-spec compliant Symbols which are polyfilled.
    if (typeof Symbol === 'function' && propValue instanceof Symbol) {
      return true;
    }

    return false;
  }

  // Equivalent of `typeof` but with special handling for array and regexp.
  function getPropType(propValue) {
    var propType = typeof propValue;
    if (Array.isArray(propValue)) {
      return 'array';
    }
    if (propValue instanceof RegExp) {
      // Old webkits (at least until Android 4.0) return 'function' rather than
      // 'object' for typeof a RegExp. We'll normalize this here so that /bla/
      // passes PropTypes.object.
      return 'object';
    }
    if (isSymbol(propType, propValue)) {
      return 'symbol';
    }
    return propType;
  }

  // This handles more types than `getPropType`. Only used for error messages.
  // See `createPrimitiveTypeChecker`.
  function getPreciseType(propValue) {
    if (typeof propValue === 'undefined' || propValue === null) {
      return '' + propValue;
    }
    var propType = getPropType(propValue);
    if (propType === 'object') {
      if (propValue instanceof Date) {
        return 'date';
      } else if (propValue instanceof RegExp) {
        return 'regexp';
      }
    }
    return propType;
  }

  // Returns a string that is postfixed to a warning about an invalid type.
  // For example, "undefined" or "of type array"
  function getPostfixForTypeWarning(value) {
    var type = getPreciseType(value);
    switch (type) {
      case 'array':
      case 'object':
        return 'an ' + type;
      case 'boolean':
      case 'date':
      case 'regexp':
        return 'a ' + type;
      default:
        return type;
    }
  }

  // Returns class name of the object, if any.
  function getClassName(propValue) {
    if (!propValue.constructor || !propValue.constructor.name) {
      return ANONYMOUS;
    }
    return propValue.constructor.name;
  }

  ReactPropTypes.checkPropTypes = checkPropTypes_1;
  ReactPropTypes.PropTypes = ReactPropTypes;

  return ReactPropTypes;
};

var factoryWithThrowingShims = function() {
  function shim(props, propName, componentName, location, propFullName, secret) {
    if (secret === ReactPropTypesSecret_1) {
      // It is still safe when called from React.
      return;
    }
    invariant_1(
      false,
      'Calling PropTypes validators directly is not supported by the `prop-types` package. ' +
      'Use PropTypes.checkPropTypes() to call them. ' +
      'Read more at http://fb.me/use-check-prop-types'
    );
  }
  shim.isRequired = shim;
  function getShim() {
    return shim;
  }
  // Important!
  // Keep this list in sync with production version in `./factoryWithTypeCheckers.js`.
  var ReactPropTypes = {
    array: shim,
    bool: shim,
    func: shim,
    number: shim,
    object: shim,
    string: shim,
    symbol: shim,

    any: shim,
    arrayOf: getShim,
    element: shim,
    instanceOf: getShim,
    node: shim,
    objectOf: getShim,
    oneOf: getShim,
    oneOfType: getShim,
    shape: getShim
  };

  ReactPropTypes.checkPropTypes = emptyFunction_1;
  ReactPropTypes.PropTypes = ReactPropTypes;

  return ReactPropTypes;
};

var index = createCommonjsModule(function (module) {
/**
 * Copyright 2013-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * LICENSE file in the root directory of this source tree. An additional grant
 * of patent rights can be found in the PATENTS file in the same directory.
 */

if (process.env.NODE_ENV !== 'production') {
  var REACT_ELEMENT_TYPE = (typeof Symbol === 'function' &&
    Symbol.for &&
    Symbol.for('react.element')) ||
    0xeac7;

  var isValidElement = function(object) {
    return typeof object === 'object' &&
      object !== null &&
      object.$$typeof === REACT_ELEMENT_TYPE;
  };

  // By explicitly using `prop-types` you are opting into new development behavior.
  // http://fb.me/prop-types-in-prod
  var throwOnDirectAccess = true;
  module.exports = factoryWithTypeCheckers(isValidElement, throwOnDirectAccess);
} else {
  // By explicitly using `prop-types` you are opting into new production behavior.
  // http://fb.me/prop-types-in-prod
  module.exports = factoryWithThrowingShims();
}
});

var _templateObject$6 = taggedTemplateLiteral(['\n    background-color: ', ';\n\n    &[href] {\n      &:hover {\n        background-color: ', ';\n      }\n    }\n  '], ['\n    background-color: ', ';\n\n    &[href] {\n      &:hover {\n        background-color: ', ';\n      }\n    }\n  ']);

function badgeVariant(color) {
  return styled.css(_templateObject$6, color, polished.darken(0.1, color));
}

var _templateObject$5 = taggedTemplateLiteral(['\n  display: inline-block;\n  ', '\n  font-size: ', ';\n  font-weight: ', ';\n  line-height: 1;\n  color: ', ';\n  text-align: center;\n  white-space: nowrap;\n  vertical-align: baseline;\n  -styled-mixin: ', ';\n\n  /* Empty badges collapse automatically */\n  &:empty {\n    display: none;\n  }\n\n  ', '\n\n  ', '\n'], ['\n  display: inline-block;\n  ', '\n  font-size: ', ';\n  font-weight: ', ';\n  line-height: 1;\n  color: ', ';\n  text-align: center;\n  white-space: nowrap;\n  vertical-align: baseline;\n  -styled-mixin: ', ';\n\n  /* Empty badges collapse automatically */\n  &:empty {\n    display: none;\n  }\n\n  ', '\n\n  ', '\n']);
var _templateObject2$2 = taggedTemplateLiteral(['\n    padding-right: ', ';\n    padding-left: ', ';\n    ', ';\n  '], ['\n    padding-right: ', ';\n    padding-left: ', ';\n    ', ';\n  ']);

var Badge = styled__default.span(_templateObject$5, function (props) {
  return 'padding: ' + props.theme.badgePaddingY + ' ' + props.theme.badgePaddingX + ';';
}, function (props) {
  return props.theme.badgeFontSize;
}, function (props) {
  return props.badgeFontWeight;
}, function (props) {
  return props.theme.badgeColor;
}, borderRadius(), function (_ref) {
  var theme = _ref.theme,
      color = _ref.color;

  switch (color) {
    case 'default':
      return badgeVariant(theme.badgeDefaultBg);
    case 'primary':
      return badgeVariant(theme.badgePrimaryBg);
    case 'success':
      return badgeVariant(theme.badgeSuccessBg);
    case 'info':
      return badgeVariant(theme.badgeInfoBg);
    case 'warning':
      return badgeVariant(theme.badgeWarningBg);
    case 'danger':
      return badgeVariant(theme.badgeDangerBg);
    default:
      return badgeVariant(theme.badgeDefaultBg);
  }
}, function (_ref2) {
  var theme = _ref2.theme,
      pill = _ref2.pill;
  return pill && styled.css(_templateObject2$2, theme.badgePillPaddingX, theme.badgePillPaddingX, borderRadius(theme.badgePillBorderRadius));
});

Badge.propTypes = {
  color: index.oneOf(['default', 'primary', 'success', 'info', 'warning', 'danger']),
  pill: index.bool
};

Badge.defaultProps = {
  color: 'default',
  pill: false,
  theme: {
    badgeDefaultBg: badgeDefaultBg,
    badgePrimaryBg: badgePrimaryBg,
    badgeSuccessBg: badgeSuccessBg,
    badgeInfoBg: badgeInfoBg,
    badgeWarningBg: badgeWarningBg,
    badgeDangerBg: badgeDangerBg,

    badgeColor: badgeColor,
    badgeLinkHoverColor: badgeLinkHoverColor,
    badgeFontSize: badgeFontSize,
    badgeFontWeight: badgeFontWeight,
    badgePaddingY: badgePaddingY,
    badgePaddingX: badgePaddingX,

    badgePillPaddingX: badgePillPaddingX,
    badgePillBorderRadius: badgePillBorderRadius
  }
};

var _templateObject$7 = taggedTemplateLiteral(['\n  ', ';\n  margin-bottom: 1rem;\n  list-style: none;\n  background-color: ', ';\n\n  ', ';\n  ', '\n'], ['\n  ', ';\n  margin-bottom: 1rem;\n  list-style: none;\n  background-color: ', ';\n\n  ', ';\n  ', '\n']);
var _templateObject2$3 = taggedTemplateLiteral(['\n  float: left;\n\n  + :before {\n    display: inline-block;\n    padding-right: ', ';\n    padding-left: ', ';\n    color: ', ';\n    content: ', ';\n  }\n\n  &:hover::before {\n    text-decoration: underline;\n  }\n\n  &:hover::before {\n    text-decoration: none;\n  }\n\n  ', '\n'], ['\n  float: left;\n\n  + :before {\n    display: inline-block;\n    padding-right: ', ';\n    padding-left: ', ';\n    color: ', ';\n    content: ', ';\n  }\n\n  &:hover::before {\n    text-decoration: underline;\n  }\n\n  &:hover::before {\n    text-decoration: none;\n  }\n\n  ', '\n']);

var Breadcrumb = styled__default.div(_templateObject$7, function (_ref) {
  var theme = _ref.theme;
  return 'padding: ' + theme.breadcrumbPaddingY + ' ' + theme.breadcrumbPaddingX + ';';
}, function (props) {
  return props.theme.breadcrumbBg;
}, function (props) {
  return borderRadius(props.theme.bordeRadius);
}, polished.clearFix());

Breadcrumb.Item = styled__default.a(_templateObject2$3, function (_ref2) {
  var theme = _ref2.theme;
  return theme.breadcrumbItemPadding;
}, function (_ref3) {
  var theme = _ref3.theme;
  return theme.breadcrumbItemPadding;
}, function (_ref4) {
  var theme = _ref4.theme;
  return theme.breadcrumbDividerColor;
}, function (_ref5) {
  var theme = _ref5.theme;
  return theme.breadcrumbDivider;
}, function (_ref6) {
  var active = _ref6.active,
      theme = _ref6.theme;
  return active && 'color: ' + theme.breadcrumbActiveColor + ' !important;';
});

var theme = {
  breadcrumbPaddingY: breadcrumbPaddingY,
  breadcrumbPaddingX: breadcrumbPaddingX,
  breadcrumbItemPadding: breadcrumbItemPadding,
  breadcrumbBg: breadcrumbBg,
  breadcrumbDividerColor: breadcrumbDividerColor,
  breadcrumbActiveColor: breadcrumbActiveColor,
  breadcrumbDivider: breadcrumbDivider
};

Breadcrumb.defaultProps = { theme: theme };
Breadcrumb.Item.defaultProps = { theme: theme };

var _templateObject$10 = taggedTemplateLiteral(['\n      box-shadow: ', ';\n    '], ['\n      box-shadow: ', ';\n    ']);

var boxShadow = function boxShadow(shadow) {
  if (enableShadows) {
    return styled.css(_templateObject$10, shadow);
  }
};

var _templateObject$9 = taggedTemplateLiteral(['\n    color: ', ';\n    background-color: ', ';\n    border-color: ', ';\n\n    ', '\n\n    // Hover and focus styles are shared\n    ', '\n\n    &:focus,\n    &.focus {\n      // Avoid using mixin so we can pass custom focus shadow properly\n      // @if $enable-shadows {\n      //   box-shadow: $btn-box-shadow, 0 0 0 2px rgba(', ', .5);\n      // } @else {\n      //   box-shadow: 0 0 0 2px rgba(', ', .5);\n      // }\n    }\n\n    // Disabled comes first so active can properly restyle\n    &.disabled,\n    &:disabled {\n      background-color: ', ';\n      border-color: ', ';\n    }\n\n    &:active,\n    &.active,\n    .show > &.dropdown-toggle {\n      color: ', ';\n      background-color: ', ';\n      background-image: none; // Remove the gradient for the pressed/active state\n      border-color: ', ';\n      // @include box-shadow($btn-active-box-shadow);\n    }\n  '], ['\n    color: ', ';\n    background-color: ', ';\n    border-color: ', ';\n\n    ', '\n\n    // Hover and focus styles are shared\n    ', '\n\n    &:focus,\n    &.focus {\n      // Avoid using mixin so we can pass custom focus shadow properly\n      // @if $enable-shadows {\n      //   box-shadow: $btn-box-shadow, 0 0 0 2px rgba(', ', .5);\n      // } @else {\n      //   box-shadow: 0 0 0 2px rgba(', ', .5);\n      // }\n    }\n\n    // Disabled comes first so active can properly restyle\n    &.disabled,\n    &:disabled {\n      background-color: ', ';\n      border-color: ', ';\n    }\n\n    &:active,\n    &.active,\n    .show > &.dropdown-toggle {\n      color: ', ';\n      background-color: ', ';\n      background-image: none; // Remove the gradient for the pressed/active state\n      border-color: ', ';\n      // @include box-shadow($btn-active-box-shadow);\n    }\n  ']);
var _templateObject2$5 = taggedTemplateLiteral(['\n      inset 0 1px 0 rgba(', ', 0.15), 0 1px 1px rgba(', ', 0.075)\n    '], ['\n      inset 0 1px 0 rgba(', ', 0.15), 0 1px 1px rgba(', ', 0.075)\n    ']);
var _templateObject3$3 = taggedTemplateLiteral(['\n      color: ', ';\n      background-color: ', ';\n      border-color: ', ';\n    '], ['\n      color: ', ';\n      background-color: ', ';\n      border-color: ', ';\n    ']);
var _templateObject4$3 = taggedTemplateLiteral(['\n    color: ', ';\n    background-image: none;\n    background-color: transparent;\n    border-color: ', ';\n\n    ', ';\n\n    &:focus,\n    &.focus {\n      box-shadow: 0 0 0 2px rgba(', ', .5);\n    }\n\n    &.disabled,\n    &:disabled {\n      color: ', ';\n      background-color: transparent;\n    }\n\n    &:active,\n    &.active,\n    .show > &.dropdown-toggle {\n      color: ', ';\n      background-color: ', ';\n      border-color: ', ';\n    }\n  '], ['\n    color: ', ';\n    background-image: none;\n    background-color: transparent;\n    border-color: ', ';\n\n    ', ';\n\n    &:focus,\n    &.focus {\n      box-shadow: 0 0 0 2px rgba(', ', .5);\n    }\n\n    &.disabled,\n    &:disabled {\n      color: ', ';\n      background-color: transparent;\n    }\n\n    &:active,\n    &.active,\n    .show > &.dropdown-toggle {\n      color: ', ';\n      background-color: ', ';\n      border-color: ', ';\n    }\n  ']);
var _templateObject5$3 = taggedTemplateLiteral(['\n    padding: ', ' ', ';\n    font-size: ', ';\n    line-height: ', ';\n    ', '\n  '], ['\n    padding: ', ' ', ';\n    font-size: ', ';\n    line-height: ', ';\n    ', '\n  ']);

function buttonVariant(color, background, border) {
  var activeBackground = polished.darken(0.1, background);
  var activeBorder = polished.darken(0.12, border);

  return styled.css(_templateObject$9, color, background, border, boxShadow(styled.css(_templateObject2$5, white, black)), hover(styled.css(_templateObject3$3, color, activeBackground, activeBorder)), border, border, background, border, color, activeBackground, activeBorder);
}

function buttonOutlineVariant(color) {
  var colorHover = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '#fff';

  return styled.css(_templateObject4$3, color, color, hover(styled.css(_templateObject3$3, colorHover, color, color)), color, color, colorHover, color, color);
}

function buttonSize(paddingY, paddingX, fontSize, lineHeight, radius) {
  return styled.css(_templateObject5$3, paddingY, paddingX, fontSize, lineHeight, borderRadius(radius));
}

var _templateObject$11 = taggedTemplateLiteral(['\n      transition: ', ';\n    '], ['\n      transition: ', ';\n    ']);
var _templateObject2$6 = taggedTemplateLiteral(['\n      transition: ', ';\n  '], ['\n      transition: ', ';\n  ']);

var transition = function transition(_transition) {
  if (enableTransitions) {
    return styled.css(_templateObject$11, transitionBase);
  }

  return styled.css(_templateObject2$6, _transition);
};

var _templateObject$8 = taggedTemplateLiteral(['\n  display: inline-block;\n  font-weight: ', ';\n  text-align: center;\n  white-space: nowrap;\n  vertical-align: middle;\n  user-select: none;\n  border: ', ' solid transparent;\n\n  ', '\n\n  ', '\n\n  // Share hover and focus styles\n  ', '\n\n  &:focus,\n  &.focus {\n    outline: 0;\n    box-shadow: ', ';\n  }\n\n  &.disabled,\n  &:disabled {\n    cursor: ', ';\n    opacity: .65;\n    // @include box-shadow(none);\n  }\n\n  ', '\n\n  ', '\n\n  ', '\n\n  ', '\n\n  ', '\n\n  ', '\n\n  ', '\n'], ['\n  display: inline-block;\n  font-weight: ', ';\n  text-align: center;\n  white-space: nowrap;\n  vertical-align: middle;\n  user-select: none;\n  border: ', ' solid transparent;\n\n  ', '\n\n  ', '\n\n  // Share hover and focus styles\n  ', '\n\n  &:focus,\n  &.focus {\n    outline: 0;\n    box-shadow: ', ';\n  }\n\n  &.disabled,\n  &:disabled {\n    cursor: ', ';\n    opacity: .65;\n    // @include box-shadow(none);\n  }\n\n  ', '\n\n  ', '\n\n  ', '\n\n  ', '\n\n  ', '\n\n  ', '\n\n  ', '\n']);
var _templateObject2$4 = taggedTemplateLiteral(['\n    text-decoration: none;\n  '], ['\n    text-decoration: none;\n  ']);
var _templateObject3$2 = taggedTemplateLiteral(['\n    font-weight: ', ';\n    color: ', ';\n    border-radius: 0;\n\n    &,\n    &:active,\n    &.active,\n    &:disabled {\n      background-color: transparent;\n      /** @include box-shadow(none); */\n    }\n\n    &,\n    &:focus,\n    &:active {\n      border-color: transparent;\n    }\n\n    ', '\n\n    ', '\n\n    &:disabled {\n      color: ', ';\n\n      ', '\n    }\n  '], ['\n    font-weight: ', ';\n    color: ', ';\n    border-radius: 0;\n\n    &,\n    &:active,\n    &.active,\n    &:disabled {\n      background-color: transparent;\n      /** @include box-shadow(none); */\n    }\n\n    &,\n    &:focus,\n    &:active {\n      border-color: transparent;\n    }\n\n    ', '\n\n    ', '\n\n    &:disabled {\n      color: ', ';\n\n      ', '\n    }\n  ']);
var _templateObject4$2 = taggedTemplateLiteral(['\n      border-color: transparent;\n    '], ['\n      border-color: transparent;\n    ']);
var _templateObject5$2 = taggedTemplateLiteral(['\n      color: ', ';\n      text-decoration: ', ';\n      background-color: transparent;\n    '], ['\n      color: ', ';\n      text-decoration: ', ';\n      background-color: transparent;\n    ']);
var _templateObject6$1 = taggedTemplateLiteral(['\n        text-decoration: none;\n      '], ['\n        text-decoration: none;\n      ']);
var _templateObject7$1 = taggedTemplateLiteral(['\n    background-image: none;\n    // ', '\n  '], ['\n    background-image: none;\n    // ', '\n  ']);
var _templateObject8 = taggedTemplateLiteral(['\n    display: block;\n    width: 100%;\n  '], ['\n    display: block;\n    width: 100%;\n  ']);

var Button = styled__default.button(_templateObject$8, function (props) {
  return props.theme.btnFontWeight;
}, function (props) {
  return props.theme.inputBtnBorderWidth;
}, function (props) {
  return !props.size && buttonSize(props.theme.inputBtnPaddingY, props.theme.inputBtnPaddingX, props.theme.fontSizeBase, props.theme.inputBtnLineHeight, props.theme.btnBorderRadius);
}, function (props) {
  return transition(props.theme.btnTransition);
}, hoverFocus(styled.css(_templateObject2$4)), function (props) {
  return props.theme.btnFocusBoxShadow;
}, function (props) {
  return props.theme.cursorDisabled;
}, function (_ref) {
  var theme = _ref.theme,
      color = _ref.color;

  switch (color) {
    case 'primary':
      return buttonVariant(theme.btnPrimaryColor, theme.btnPrimaryBg, theme.btnPrimaryBorderColor);
    case 'secondary':
      return buttonVariant(theme.btnSecondaryColor, theme.btnSecondaryBg, theme.btnSecondaryBorderColor);
    case 'info':
      return buttonVariant(theme.btnInfoColor, theme.btnInfoBg, theme.btnInfoBorderColor);
    case 'success':
      return buttonVariant(theme.btnSuccessColor, theme.btnSuccessBg, theme.btnSuccessBorderColor);
    case 'warning':
      return buttonVariant(theme.btnWarningColor, theme.btnWarningBg, theme.btnWarningBorderColor);
    case 'danger':
      return buttonVariant(theme.btnDangerColor, theme.btnDangerBg, theme.btnDangerBorderColor);
    default:
      return null;
  }
}, function (props) {
  return props.color === 'link' && styled.css(_templateObject3$2, function (props) {
    return props.theme.fontWeightNormal;
  }, function (props) {
    return props.theme.linkColor;
  }, hover(styled.css(_templateObject4$2)), hoverFocus(styled.css(_templateObject5$2, function (props) {
    return props.theme.linkHoverColor;
  }, function (props) {
    return props.theme.linkHoverDecoration;
  })), btnLinkDisabledColor, hoverFocus(styled.css(_templateObject6$1)));
}, function (_ref2) {
  var theme = _ref2.theme,
      outline = _ref2.outline,
      color = _ref2.color;

  if (outline) {
    switch (color) {
      case 'primary':
        return buttonOutlineVariant(theme.btnPrimaryBg);
      case 'secondary':
        return buttonOutlineVariant(theme.btnSecondaryBorder);
      case 'info':
        return buttonOutlineVariant(theme.btnInfoBg);
      case 'success':
        return buttonOutlineVariant(theme.btnSuccessBg);
      case 'warning':
        return buttonOutlineVariant(theme.btnWarningBg);
      case 'danger':
        return buttonOutlineVariant(theme.btnDangerBg);
      default:
        return null;
    }
  }
}, function (props) {
  return props.size === 'large' && buttonSize(props.theme.inputBtnPaddingYlg, props.theme.inputBtnPaddingXlg, props.theme.fontSizeLg, props.theme.inputBtnLineHeightLg, props.theme.btnBorderRadiusLg);
}, function (props) {
  return props.size === 'small' && buttonSize(props.theme.inputBtnPaddingYsm, props.theme.inputBtnPaddingXsm, props.theme.fontSizeSm, props.theme.inputBtnLineHeightSm, props.theme.btnBorderRadiusSm);
}, function (props) {
  return props.active && styled.css(_templateObject7$1, boxShadow(props.theme.btnFocusBoxShadow));
}, function (props) {
  return props.block && styled.css(_templateObject8);
});

Button.Link = Button.withComponent('a');

Button.defaultProps = {
  theme: {
    inputBtnPaddingY: inputBtnPaddingY,
    inputBtnPaddingX: inputBtnPaddingX,
    inputBtnLineHeight: inputBtnLineHeight,
    inputBtnPaddingYsm: inputBtnPaddingYsm,
    inputBtnPaddingXsm: inputBtnPaddingXsm,
    inputBtnLineHeightSm: inputBtnLineHeightSm,
    inputBtnPaddingYlg: inputBtnPaddingYlg,
    inputBtnPaddingXlg: inputBtnPaddingXlg,
    inputBtnLineHeightLg: inputBtnLineHeightLg,
    btnFontWeight: btnFontWeight,
    btnBoxShadow: btnBoxShadow,
    btnFocusBoxShadow: btnFocusBoxShadow,
    btnActiveBoxShadow: btnActiveBoxShadow,
    btnPrimaryColor: btnPrimaryColor,
    btnPrimaryBg: btnPrimaryBg,
    btnPrimaryBorderColor: btnPrimaryBorderColor,
    btnSecondaryColor: btnSecondaryColor,
    btnSecondaryBg: btnSecondaryBg,
    btnSecondaryBorderColor: btnSecondaryBorderColor,
    btnInfoColor: btnInfoColor,
    btnInfoBg: btnInfoBg,
    btnInfoBorderColor: btnInfoBorderColor,
    btnSuccessColor: btnSuccessColor,
    btnSuccessBg: btnSuccessBg,
    btnSuccessBorderColor: btnSuccessBorderColor,
    btnWarningColor: btnWarningColor,
    btnWarningBg: btnWarningBg,
    btnWarningBorderColor: btnWarningBorderColor,
    btnDangerColor: btnDangerColor,
    btnDangerBg: btnDangerBg,
    btnDangerBorderColor: btnDangerBorderColor,
    btnLinkDisabledColor: btnLinkDisabledColor,
    btnBlockSpacingY: btnBlockSpacingY,
    btnBorderRadius: btnBorderRadius,
    btnBorderRadiusLg: btnBorderRadiusLg,
    btnBorderRadiusSm: btnBorderRadiusSm,
    btnTransition: btnTransition,
    fontSizeBase: fontSizeBase,
    inputBtnBorderWidth: inputBtnBorderWidth,
    fontSizeLg: fontSizeLg,
    fontSizeSm: fontSizeSm,
    fontWeightNormal: fontWeightNormal,
    linkColor: linkColor
  }
};

exports.Alert = Alert;
exports.Badge = Badge;
exports.Breadcrumb = Breadcrumb;
exports.Button = Button;
